#
# spec file for package brisk-menu
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           brisk-menu
Version:        0.6.2
Release:        2.3
Summary:        Modern, efficient menu for MATE
License:        CC-BY-SA-4.0 AND GPL-2.0-or-later
URL:            https://github.com/getsolus/brisk-menu
Source:         https://github.com/getsolus/brisk-menu/releases/download/v%{version}/%{name}-v%{version}.tar.xz
Source1:        https://github.com/getsolus/brisk-menu/releases/download/v%{version}/%{name}-v%{version}.tar.xz.asc
Source2:        %{name}.keyring
# PATCH-FIX-UPSTREAM brisk-menu-gsettings-icon-properties.patch ionic@ionic.de -- Add icon properties to the gsettings schema for runtime configuration.
Patch0:         %{name}-gsettings-icon-properties.patch
# PATCH-FIX-UPSTREAM brisk-menu-runtime-icon-updates.patch ionic@ionic.de -- Add support for runtime icon configuration.
Patch1:         %{name}-runtime-icon-updates.patch
# PATCH-FIX-UPSTREAM brisk-menu-fix-crash-on-desktop-file-changes-5f0be5741b5b37221fc8911c11f394ec498cd53d.patch anton.fadeev@red-soft.ru -- Fix crash in some random cases when .desktop files are changed.
Patch2:         %{name}-fix-crash-on-desktop-file-changes-5f0be5741b5b37221fc8911c11f394ec498cd53d.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libmate-menu) >= 1.22
BuildRequires:  pkgconfig(libmatepanelapplet-4.0) >= 1.22
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(x11)
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
Modern, efficient menu for the MATE Desktop Environment.

%prep
%autosetup -p1 -n %{name}-%{version}

%lang_package

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name}

%files
%license LICENSE*
%{_libexecdir}/brisk-menu
%dir %{_datadir}/mate-panel/
%dir %{_datadir}/mate-panel/applets/
%{_datadir}/mate-panel/applets/*brisk*.mate-panel-applet
%{_datadir}/icons/hicolor/scalable/actions/brisk*.*
%{_datadir}/glib-2.0/schemas/*%{name}.gschema.xml
%{_datadir}/dbus-1/services/org.mate.panel.applet.BriskMenuFactory.service

%files lang -f %{name}.lang

%changelog
* Fri Dec 27 2024 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
- Add patches: brisk-menu-gsettings-icon-properties.patch and
  brisk-menu-runtime-icon-updates.patch. Add support for runtime icon
  configuration.
- Add a patch: brisk-menu-fix-crash-on-desktop-file-changes-5f0be5741b5b37221fc8911c11f394ec498cd53d.patch.
  Backport upstream patch to fix crashes in odd cases when .desktop files are
  changed.
- Use %%autosetup macro to apply patches.
* Mon Aug 31 2020 Hillwood Yang <hillwood@opensuse.org>
- update version to 0.6.2
  * frontend: Allow keyboard navigation
  * applet: Re-create applet menu when changing window-type
  * backend: Hide menu when rebuilding menu items
  * Update translations.
* Sat Feb 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 0.6.1 (changes since 0.5.0):
  * Add a new "dash" style menu.
  * Fix super key global bindings on Compiz.
  * Unset Lock key masks when closing menu.
  * Fix key-binder from swallowing Super+Mouse events.
  * Update API for MATE Desktop 1.22.
  * Make favourites appear first.
  * Fix categories list so scrollbar is not always shown.
  * Update translations.
- Remove brisk-menu-mate-menus-1.22.patch: fixed upstream.
- Drop support for old openSUSE versions.
* Fri Dec 14 2018 sor.alexei@meowr.ru
- Add brisk-menu-mate-menus-1.22.patch:
  https://github.com/solus-project/brisk-menu/pull/103
* Fri Nov  3 2017 sor.alexei@meowr.ru
- Update to version 0.5.0:
  * New Favourites back end (backed by gsettings).
  * Optimised backends to ensure O(1) lookup times.
  * Extended backend actions API for context sensitive backend
    actions (pin/unpin).
  * Add ~/Desktop pin/unpin.
  * Move to meson to help with modularity.
  * Confined MATE Applet APIs to the applet component
    (not frontend/backend/etc).
  * Moved BriskKeyBinder and window positioning logic into a
    front end.
  * Mask confusing inverted MatePanelAppletOrient in favour of
    GtkPositionType.
  * Update translations.
* Wed Jul  5 2017 thanosapostolou@outlook.com
- Update to version 0.4.5 (changes since 0.3.5):
  * The Super key now works.
  * The Label text is now configurable.
  * The menu now dynamically adapts to vertical panel layouts.
  * The core load + management mechanism is now handled by a
    BriskAppsBackend, and the front end is no longer tied
    explicitly to libmate-menus or even .desktop files. This opens
    up the future possibilities for Favourites Pinning and "others"
    (...) through the generic BriskBackend, BriskItem, and
    BriskSection API.
  * Reloading has been changed and fixed, always works (part of
    the new BriskAppsBackend, signal based).
  * Control Centre applications are now listed in Preferences and
    Administration categories.
  * Add full vertical panel support.
  * Switch everything to backends (All button is now a backend too).
  * Dynamically size menu to the best size available on the screen.
  * Fix Super key binding being swallowed by others (and swallowing
    theirs) - requires fixes in Albert, MATE Settings Daemon, etc.
  * Update translations.
* Wed Mar 29 2017 sor.alexei@meowr.ru
- Update to version 0.3.5:
  * Fix bitwise operators on search bar placement (inverse logic).
  * Standardise the CSS usage, fix broken assets.
  * Add rollover behaviour (a gsettings option).
  * Add a context menu for editing menus.
  * Style fixes (new CSS classes).
  * Update translations.
* Wed Jan 25 2017 sor.alexei@meowr.ru
- Update to version 0.3.0:
  * Fix a bug with a terminal + applications opening in the root
    directory.
  * Fix duplicate results in the search bar.
  * Fix missing icons in listing.
  * Fix searching to be case insensitive.
  * Provide compiler hints to hot paths within Brisk.
  * Add basic keyword filtering (i.e. video for VLC).
  * Enable internationalisation.
  * Fully reset the menu state & focus between appearances.
  * Add GSettings support for search bar placement (top, bottom,
    automatic).
* Sun Jan  1 2017 sor.alexei@meowr.ru
- Update to version 0.2.0:
  * Initial GSettings support.
  * Load sidebar shortcuts according to the vendor schema
    (pinned-shortcuts).
  * Add a key to control dark-theme.
* Sat Dec 31 2016 sor.alexei@meowr.ru
- Update to version 0.1.2:
  * Use a less janky button style for the session controls.
  * Include autogen.sh.
* Sat Dec 31 2016 sor.alexei@meowr.ru
- Initial package.
